SELECT postgis_EnableLongTransactions();

CREATE TABLE test_locks (id numeric, state varchar);
INSERT INTO test_locks(id) VALUES (1);
INSERT INTO test_locks(id) VALUES (2);
INSERT INTO test_locks(id) VALUES (3);

-- enable locks checking on the table
SELECT postgis_CheckAuth('test_locks', 'id');

-- this has no lock
UPDATE test_locks SET state = 'nolocks';

-- place the lock
SELECT postgis_LockRow('test_locks', '1', 'auth1', now()::timestamp + '00:01');
SELECT postgis_LockRow('test_locks', '2', 'auth2', now()::timestamp + '00:01');

-- this should fail due to missing auth
UPDATE test_locks SET state = 'unauthorized' where id = 1;

BEGIN;

	-- add authorization for row 1
	SELECT postgis_AddAuth('auth1');

	-- we're authorized for row 1
	UPDATE test_locks SET state = 'authorized' where id = 1;

END;

-- out of transaction we're no more authorized for row 1
UPDATE test_locks SET state = 'unauthorized' where id = 1;

BEGIN;

	-- add authorization for row 2
	SELECT postgis_AddAuth('auth2');

	-- we're authorized for row 2
	UPDATE test_locks SET state = 'authorized' where id = 2;

END;


BEGIN;

	-- add authorization for row 2
	SELECT postgis_AddAuth('auth2');
	
	-- we're not authorized for row 1
	UPDATE test_locks SET state = 'unauthorized' where id = 1;

END;

UPDATE test_locks SET state = 'unauthorized' where id = 2;
UPDATE test_locks SET state = 'unauthorized' where id = 1;

SELECT * from test_locks;

DROP TABLE test_locks;

SELECT postgis_DisableLongTransactions();